summaryrefslogtreecommitdiff
path: root/sw/inc/swmodule.hxx
diff options
context:
space:
mode:
authorjp <jp@openoffice.org>2001-09-11 13:43:25 +0000
committerjp <jp@openoffice.org>2001-09-11 13:43:25 +0000
commitad770812336bc54167d6a2c776213a35e812451c (patch)
tree4f6432cb44ef3f393c556c611326ed3f0fb20d7c /sw/inc/swmodule.hxx
parentf6486c6186ca1f2c55196b72052f6082baa2881e (diff)
Task #91678#: 'selection clipbord' implemented
Diffstat (limited to 'sw/inc/swmodule.hxx')
-rw-r--r--sw/inc/swmodule.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sw/inc/swmodule.hxx b/sw/inc/swmodule.hxx
index 9f10275d33a0..696cb30abd6b 100644
--- a/sw/inc/swmodule.hxx
+++ b/sw/inc/swmodule.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: swmodule.hxx,v $
*
- * $Revision: 1.10 $
+ * $Revision: 1.11 $
*
- * last change: $Author: os $ $Date: 2001-06-25 13:42:09 $
+ * last change: $Author: jp $ $Date: 2001-09-11 14:43:25 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -168,8 +168,8 @@ protected:
void InsertLab(SfxRequest&, sal_Bool bLabel);
public:
- // public Data - used for internal Clipboard / Drag & Drop
- SwTransferable *pClipboard, *pDragDrop;
+ // public Data - used for internal Clipboard / Drag & Drop / XSelection
+ SwTransferable *pClipboard, *pDragDrop, *pXSelection;
TYPEINFO();